@@ -60,6 +60,8 @@ import textwrap
 from typing import Any, Dict, Callable, Union, Tuple, Optional, Mapping, List, TYPE_CHECKING
 from itertools import chain, islice
 
+from nanoutils import raise_if
+
 from .functions import set_docstring
 
 if TYPE_CHECKING:
@@ -101,14 +103,14 @@ else:
 
 try:
     import numpy as np
-    NUMPY_EX: Optional[ImportError] = None
-except ImportError as ex:
+    NUMPY_EX: Optional[Exception] = None
+except Exception as ex:
     NUMPY_EX = ex
 
 try:
     import pandas as pd
-    PANDAS_EX: Optional[ImportError] = None
-except ImportError as ex:
+    PANDAS_EX: Optional[Exception] = None
+except Exception as ex:
     PANDAS_EX = ex
 
 __all__ = ['NDRepr', 'aNDRepr']
@@ -126,25 +128,6 @@ class NDRepr(reprlib.Repr):
         * Pandas Series and DataFrames
         * Callables
 
-    Examples
-    --------
-    See :mod:`reprlib` for more details.
-
-    code:: python
-
-        >>> from assertionlib.ndrepr import aNDRepr
-        >>> import numpy as np
-
-        >>> object = np.ones((100, 100), dtype=float)
-        >>> print(aNDRepr.repr(object))
-        array([[1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000],
-               [1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000],
-               [1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000],
-               ...,
-               [1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000],
-               [1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000],
-               [1.0000, 1.0000, 1.0000, ..., 1.0000, 1.0000, 1.0000]])
-
     Parameters
     ----------
     **kwargs : object
@@ -405,11 +388,9 @@ class NDRepr(reprlib.Repr):
 
     # NumPy- and Pandas-related methods
 
+    @raise_if(NUMPY_EX)
     def repr_ndarray(self, obj: ndarray, level: int) -> str:
         """Create a :class:`str` representation of a :class:`numpy.ndarray` instance."""
-        if NUMPY_EX is not None:
-            raise NUMPY_EX
-
         if level <= 0:
             return f'{obj.__class__.__name__}(...)'
 
@@ -421,11 +402,9 @@ class NDRepr(reprlib.Repr):
         with np.printoptions(**kwargs):
             return builtins.repr(obj)
 
+    @raise_if(PANDAS_EX)
     def repr_DataFrame(self, obj: DataFrame, level: int) -> str:  # noqa: N802
         """Create a :class:`str` representation of a :class:`pandas.DataFrame` instance."""
-        if PANDAS_EX is not None:
-            raise PANDAS_EX
-
         if level <= 0:
             return f'{obj.__class__.__name__}(...)'
 
